Library IEEE;
USE IEEE.std_logic_1164.all;
USE IEEE.std_logic_unsigned.all;

USE work.pkg_081006.all;

----------------------------------------------------
-- This module provides timing and control for the
-- Booster BLM Integrator control.

entity detect_jumper is
port(
		clk			: in std_logic;
		nreset		: in std_logic;
		
		In_1		: in std_logic;
		In_2		: in std_logic;
		In_3		: in std_logic;
		In_4		: in std_logic;

		Clk_1		: out std_logic;
		Clk_2		: out std_logic;
		Clk_3		: out std_logic;
		Clk_4		: out std_logic;
		
		Jumped1	: out std_logic;
		Jumped2	: out std_logic;
		Jumped3	: out std_logic;
		Jumped4	: out std_logic
		      
	);
end detect_jumper;

--########################################################
--				A R C H I T E C T U R E
--########################################################
architecture main of detect_jumper is

-- Synchronized Input Signals --------------------------------
	signal rst_1	: std_logic;
	signal rst_2	: std_logic;
	signal rst_3	: std_logic;
	signal rst_4	: std_logic;
	
	signal cnt1	: std_logic_vector(1 downto 0);
	signal cnt2	: std_logic_vector(1 downto 0);
	signal cnt3	: std_logic_vector(1 downto 0);
	signal cnt4	: std_logic_vector(1 downto 0);
	
	signal source : std_logic_vector(1 downto 0);

--========================================================
--						B E G I N
--========================================================
begin

SYNC_1: led 
	port map(sig_in=>In_1, clk=>clk,	clrn=>nreset, pls_out=>rst_1); 
SYNC_2: led 
	port map(sig_in=>In_2, clk=>clk,	clrn=>nreset, pls_out=>rst_2); 
SYNC_3: led 
	port map(sig_in=>In_3, clk=>clk,	clrn=>nreset, pls_out=>rst_3); 
SYNC_4: led 
	port map(sig_in=>In_4, clk=>clk,	clrn=>nreset, pls_out=>rst_4); 

SOURCE_CLOCKS: 
process(clk, nreset)
begin
	if(nreset='0')	then source <= "00";
	elsif(rising_edge(clk))	then source <= source + 1;
	end if;
end process;

Clk_1 <= source(0);
Clk_2 <= source(0);
Clk_3 <= source(0);
Clk_4 <= source(0);

------------------------------------------------------------
CLOCK_DETECTION:
process(clk, nreset, rst_1, rst_2, rst_3, rst_4)
begin
	if   (nreset = '0' or rst_1 = '1') then cnt1 <= "00";
											Jumped1 <= '1';
	elsif(rising_edge(clk))	then 
		if(cnt1 < "11")		then cnt1 <= cnt1 + 1;
								 Jumped1 <= '1';
		else					 cnt1 <= cnt1;
								 Jumped1 <= '0';
		end if;
	end if;
	---------
	if   (nreset = '0' or rst_2 = '1') then cnt2 <= "00";
											Jumped2 <= '1';
	elsif(rising_edge(clk))	then 
		if(cnt2 < "11")		then cnt2 <= cnt2 + 1;
								 Jumped2 <= '1';
		else					 cnt2 <= cnt2;
								 Jumped2 <= '0';
		end if;
	end if;
	---------	
	if   (nreset = '0' or rst_3 = '1') then cnt3 <= "00";
											Jumped3 <= '1';
	elsif(rising_edge(clk))	then 
		if(cnt3 < "11")		then cnt3 <= cnt3 + 1;
								 Jumped3 <= '1';
		else					 cnt3 <= cnt3;
								 Jumped3 <= '0';
		end if;
	end if;
	---------	
	if   (nreset = '0' or rst_4 = '1') then cnt4 <= "00";
											Jumped4 <= '1';
	elsif(rising_edge(clk))	then 
		if(cnt4 < "11")		then cnt4 <= cnt4 + 1;
								 Jumped4 <= '1';
		else				 	 cnt4 <= cnt4;
								 Jumped4 <= '0';
		end if;
	end if;
		
end process;

end;

